<?php
namespace BdevsElementor\Widget;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;

/**
 * Bdevs Elementor Widget.
 *
 * Elementor widget that inserts an embbedable content into the page, from any given URL.
 *
 * @since 1.0.0
 */
class BdevsCases extends \Elementor\Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Bdevs Elementor widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'bdevs-cases';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Bdevs Elementor widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Cases', 'bdevs-elementor' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Bdevs Slider widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-post-content';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Bdevs Slider widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'bdevs-elementor' ];
	}

	public function get_keywords() {
		return [ 'cases', 'carousel' ];
	}

	public function get_script_depends() {
		return [ 'bdevs-elementor'];
	}

	// BDT Position
	protected function element_pack_position() {
	    $position_options = [
	        ''              => esc_html__('Default', 'bdevs-elementor'),
	        'top-left'      => esc_html__('Top Left', 'bdevs-elementor') ,
	        'top-center'    => esc_html__('Top Center', 'bdevs-elementor') ,
	        'top-right'     => esc_html__('Top Right', 'bdevs-elementor') ,
	        'center'        => esc_html__('Center', 'bdevs-elementor') ,
	        'center-left'   => esc_html__('Center Left', 'bdevs-elementor') ,
	        'center-right'  => esc_html__('Center Right', 'bdevs-elementor') ,
	        'bottom-left'   => esc_html__('Bottom Left', 'bdevs-elementor') ,
	        'bottom-center' => esc_html__('Bottom Center', 'bdevs-elementor') , 
	        'bottom-right'  => esc_html__('Bottom Right', 'bdevs-elementor') ,
	    ];

	    return $position_options;
	}

	protected function _register_controls() {
		$this->start_controls_section(
			'section_content_cases',
			[
				'label' => esc_html__( 'Cases', 'bdevs-elementor' ),
			]
		);		
		$this->add_control(
			'title',
			[
				'label'       => __( 'Title', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your title', 'bdevs-elementor' ),
				'default'     => __( 'Title', 'bdevs-elementor' ),
				'label_block' => true,
			]	
		);	
		$this->add_control(
			'number_posts_page',
			[
				'label'       => __( 'Number Posts Page', 'bdevs-elementor' ),
				'type'        => Controls_Manager::NUMBER,
				'placeholder' => __( 'Enter your title', 'bdevs-elementor' ),
				'default'     => __( '', 'bdevs-elementor' ),
				'label_block' => true,
			]	
		);	
		$this->end_controls_section();

		$this->start_controls_section(
			'section_content_layout',
			[
				'label' => esc_html__( 'Layout', 'bdevs-elementor' ),
			]
		);

		$this->add_responsive_control(
			'align',
			[
				'label'   => esc_html__( 'Alignment', 'bdevs-elementor' ),
				'type'    => Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => esc_html__( 'Left', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-center',
					],
					'right' => [
						'title' => esc_html__( 'Right', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-right',
					],
					'justify' => [
						'title' => esc_html__( 'Justified', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-justify',
					],
				],
				'prefix_class' => 'elementor%s-align-',
				'description'  => 'Use align to match position',
				'default'      => 'left',
			]
		);

		$this->add_control(
			'show_title',
			[
				'label'   => esc_html__( 'Show Title', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);				

		$this->end_controls_section();

	}

	public function render() {

		$settings  = $this->get_settings_for_display();
		extract($settings);
		$bg_src = wp_get_attachment_image_src( $settings['background_bg']['id'], 'full' );
		$bg_url = $bg_src ? $bg_src[0] : '';
		$number_page = wp_kses_post($settings['number_posts_page']);
		?>  

		<?php
		    $wp_query = new \WP_Query(array('post_type' => 'cases','paged' => $paged,
		                        'posts_per_page' => $number_page,));
		    $args = array('post_type' => 'cases');
		?>
<!--================Start cases Area =================-->
<section class="our_cases_area pad_100">
    <div class="container">
        <div class="left_title">
             <?php if (( '' !== $settings['title'] ) && ( $settings['show_title'] )) : ?>
            <h2><?php echo wp_kses_post($settings['title']) ?></h2>
            <?php endif; ?>
        </div>
        <ul class="project_fillter">
            <li class="active" data-filter="*"><a href="#">All</a></li>
            <?php
                $categories = get_terms('type1');
                foreach((array)$categories as $categorie){              
                    $cat_name = $categorie->name;
                    $cat_slug = $categorie->slug;
            ?>
            <li data-filter=".<?php echo esc_attr($cat_slug);?>"><a href="#"><?php echo esc_attr($cat_name);?></a></li>
            <?php }?>
        </ul>

        <div class="row our_case_inner">
        	<?php  
                $args = new \WP_Query(array(
                        'post_type'     => 'cases',
                    ));
                    $i = 1;
                    while($wp_query->have_posts()): $wp_query->the_post(); 
                    $cates = get_the_terms(get_the_ID(),'type1');
                    $cate_name = '';
                    $cate_slug = '';
                    foreach((array)$cates as $cate){
                    if(count($cates)>0){
                        $cate_name .= $cate->name.' ' ;
                        $cate_slug .= $cate->slug .' ';     
                    } 
                }
                    $i++;
                $image_cases_gallery = get_post_meta(get_the_ID(),'_cmb_cases_featured_image_2', true);
                $title_cases = get_post_meta(get_the_ID(),'_cmb_cases_title_ex',true);
            ?>
            <div class="col-md-3 col-sm-4 col-xs-6  energy <?php echo esc_attr($cate_slug);?>">
                <div class="cases_item">
                    <div class="cases_image">
                        <img src="<?php echo wp_get_attachment_url($image_cases_gallery);?>" alt="">
                        <a class="cases_link" href="<?php the_permalink();?>"><i class="icon icon-Linked"></i></a> 
                    </div>
                    <a href="<?php the_permalink();?>"><h5><?php echo esc_attr($title_cases);?></h5></a>
                    <p>Business Analysis</p>
                </div>
            </div>
        	<?php endwhile; ?>
        </div>
    </div>
</section>
<!--================End Cases Area =================-->

<?php
}

}
