<?php
namespace BdevsElementor\Widget;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;

/** 
 * Bdevs Elementor Widget.
 *
 * Elementor widget that inserts an embbedable content into the page, from any given URL.
 *
 * @since 1.0.0
 */
class BdevsMission extends \Elementor\Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Bdevs Elementor widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'bdevs-mission';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Bdevs Elementor widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Mission', 'bdevs-elementor' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Bdevs Slider widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-calendar';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Bdevs Slider widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'bdevs-elementor' ];
	}

	public function get_keywords() {
		return [ 'welcome', 'carousel' ];
	}

	public function get_script_depends() {
		return [ 'bdevs-elementor'];
	}

	// BDT Position
	protected function element_pack_position() {
	    $position_options = [
	        ''              => esc_html__('Default', 'bdevs-elementor'),
	        'top-left'      => esc_html__('Top Left', 'bdevs-elementor') ,
	        'top-center'    => esc_html__('Top Center', 'bdevs-elementor') ,
	        'top-right'     => esc_html__('Top Right', 'bdevs-elementor') ,
	        'center'        => esc_html__('Center', 'bdevs-elementor') ,
	        'center-left'   => esc_html__('Center Left', 'bdevs-elementor') ,
	        'center-right'  => esc_html__('Center Right', 'bdevs-elementor') ,
	        'bottom-left'   => esc_html__('Bottom Left', 'bdevs-elementor') ,
	        'bottom-center' => esc_html__('Bottom Center', 'bdevs-elementor') , 
	        'bottom-right'  => esc_html__('Bottom Right', 'bdevs-elementor') ,
	    ];

	    return $position_options;
	}

	protected function _register_controls() {
		$this->start_controls_section(
			'section_content_mission',
			[
				'label' => esc_html__( 'Mission', 'bdevs-elementor' ),
			]
		);		
		$this->add_control(
			'title1',
			[
				'label'       => __( 'Title 1', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your title', 'bdevs-elementor' ),
				'default'     => __( 'Title 1', 'bdevs-elementor' ),
				'label_block' => true,
			]	
		);	
		$this->add_control(
			'subtitle1',
			[
				'label'       => __( 'Subtitle 1', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXTAREA,
				'placeholder' => __( 'Enter your subtitle', 'bdevs-elementor' ),
				'default'     => __( 'Subtitle 1', 'bdevs-elementor' ),
				'label_block' => true,
			]	
		);	
		$this->add_control(
			'subtitle2',
			[
				'label'       => __( 'Subtitle 2', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXTAREA,
				'placeholder' => __( 'Enter your subtitle', 'bdevs-elementor' ),
				'default'     => __( 'Subtitle 2', 'bdevs-elementor' ),
				'label_block' => true,
			]	
		);	
		$this->add_control(
			'image1',
			[
				'label'       => esc_html__( 'Image 1', 'bdevs-elementor' ),
				'type'        => Controls_Manager::MEDIA,
				'dynamic'     => [ 'active' => true ],
				'label_block' => true,
				'description' => esc_html__( 'Upload Image 1', 'bdevs-elementor' ),
			]	
		);	
		$this->add_control(
			'image2',
			[
				'label'       => esc_html__( 'Signature Image', 'bdevs-elementor' ),
				'type'        => Controls_Manager::MEDIA,
				'dynamic'     => [ 'active' => true ],
				'label_block' => true,
				'description' => esc_html__( 'Upload Image', 'bdevs-elementor' ),
			]	
		);	
		$this->add_control(
			'title2',
			[
				'label'       => __( 'Title 2', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your title', 'bdevs-elementor' ),
				'default'     => __( 'Title 2', 'bdevs-elementor' ),
				'label_block' => true,
			]	
		);	
		$this->add_control(
			'tabs',
			[
				'label' => esc_html__( 'List Items', 'bdevs-elementor' ),
				'type' => Controls_Manager::REPEATER,
				'default' => [
					[
						'tab_title'   => esc_html__( 'Slide #1', 'bdevs-elementor' ),
						'tab_content' => esc_html__( 'I am item content. Click edit button to change this text.', 'bdevs-elementor' ),
					]
				],
				'fields' => [
					[
						'name'        => 'title_item',
						'label'       => esc_html__( 'Title Item', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXT,
						'dynamic'     => [ 'active' => true ],
						'default'     => esc_html__( '' , 'bdevs-elementor' ),
						'label_block' => true,
					],
					[
						'name'        => 'subtitle_item',
						'label'       => esc_html__( 'SubTitle Item', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXTAREA,
						'dynamic'     => [ 'active' => true ],
						'default'     => esc_html__( '' , 'bdevs-elementor' ),
						'label_block' => true,
					],
				],
			]
		);	
	

		$this->end_controls_section();

		$this->start_controls_section(
			'section_content_layout',
			[
				'label' => esc_html__( 'Layout', 'bdevs-elementor' ),
			]
		);

		$this->add_responsive_control(
			'align',
			[
				'label'   => esc_html__( 'Alignment', 'bdevs-elementor' ),
				'type'    => Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => esc_html__( 'Left', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-center',
					],
					'right' => [
						'title' => esc_html__( 'Right', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-right',
					],
					'justify' => [
						'title' => esc_html__( 'Justified', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-justify',
					],
				],
				'prefix_class' => 'elementor%s-align-',
				'description'  => 'Use align to match position',
				'default'      => 'left',
			]
		);

		$this->add_control(
			'show_title1',
			[
				'label'   => esc_html__( 'Show Title 1', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);			

		$this->add_control(
			'show_subtitle1',
			[
				'label'   => esc_html__( 'Show Subtitle 1', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);		
		$this->add_control(
			'show_title2',
			[
				'label'   => esc_html__( 'Show Title 2', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);			

		$this->add_control(
			'show_subtitle2',
			[
				'label'   => esc_html__( 'Show Subtitle 2 ', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);		
	

		$this->end_controls_section();

	}

	public function render() {

		$settings  = $this->get_settings_for_display();
		extract($settings);
		$bg_src = wp_get_attachment_image_src( $settings['background_bg']['id'], 'full' );
		$bg_url = $bg_src ? $bg_src[0] : '';
		?>  

<!--================Start Our Mission Area =================-->
<section class="our-mission-area pad_100">
    <div class="container">
        <div class="row">
            <div class="col-md-6">
                <div class="mission-content">
                    <div class="left_title left-title2">

                        <?php if (( '' !== $settings['title1'] ) && ( $settings['show_title1'] )) : ?>
			            <h2><?php echo wp_kses_post($settings['title1']); ?></h2>
			       	 	<?php endif; ?>

                    </div>

                    <?php if (( '' !== $settings['subtitle1'] ) && ( $settings['show_subtitle1'] )) : ?>
		            <h3><?php echo wp_kses_post($settings['subtitle1']); ?></h3>
		       	 	<?php endif; ?>

                    <?php if (( '' !== $settings['subtitle2'] ) && ( $settings['show_subtitle2'] )) : ?>
		            <p><?php echo wp_kses_post($settings['subtitle2']); ?></p>
		       	 	<?php endif; ?>

                    <div class="media">
                        <div class="media-left">
                            <img class="img-circle" src="<?php print esc_url($settings['image1']['url']); ?>" alt="">
                        </div>
                        <div class="media-body">
                            <a href="#"><img src="<?php print esc_url($settings['image2']['url']); ?>" alt=""></a>
                        </div>
                    </div>
                </div>
            </div>
            <div class="col-md-6">
                        <div class="faq_accordian">
                            <div class="left_title">
                                

		                        <?php if (( '' !== $settings['title2'] ) && ( $settings['show_title2'] )) : ?>
					            <h2><?php echo wp_kses_post($settings['title2']); ?></h2>
					       	 	<?php endif; ?>

                            </div>
                            <div class="panel-group" id="accordion" role="tablist" aria-multiselectable="true">
                            	<?php $i =0 ;
						            foreach ( $settings['tabs'] as $item ) : 
								$i++;				
								?>
                                <div class="panel panel-default">
                                    <div class="panel-heading" role="tab" id="heading<?php echo esc_attr($i) ; ?>">
                                        <h4 class="panel-title">
                                            <a role="button" data-toggle="collapse" data-parent="#accordion" href="#collapse<?php echo esc_attr($i) ; ?>" aria-expanded="true" aria-controls="collapse<?php echo esc_attr($i) ; ?>">
                                                <i>+</i>
                                                <i>-</i>
                                                <?php echo wp_kses_post($item['title_item']); ?>
                                            </a>
                                        </h4>
                                    </div>
                                    <div id="collapse<?php echo esc_attr($i) ; ?>" class="panel-collapse collapse 
                                    	<?php if(esc_attr($i) == '1'){?>
						                <?php echo esc_html__( 'in', 'sorbroix' );?>
						                <?php }else{
						                    echo esc_html__( '', 'sorbroix' );
						                }?>" 
                                     " role="tabpanel" aria-labelledby="heading<?php echo esc_attr($i) ; ?>">
                                        <div class="panel-body">
                                        <?php echo wp_kses_post($item['subtitle_item']); ?>
                                        </div>
                                    </div>
                                </div>
                            	<?php endforeach; ?>
                            </div>
                        </div>
                    </div>
        </div>
    </div>
</section>
<!--================End Our Mission  Area =================-->



<?php
}

}
