<?php
namespace BdevsElementor\Widget;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;

/**
 * Bdevs Elementor Widget.
 *
 * Elementor widget that inserts an embbedable content into the page, from any given URL.
 *
 * @since 1.0.0
 */
class BdevsNews extends \Elementor\Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Bdevs Elementor widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'bdevs-news';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Bdevs Elementor widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'News', 'bdevs-elementor' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Bdevs Slider widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return ' eicon-post-slider';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Bdevs Slider widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'bdevs-elementor' ];
	}

	public function get_keywords() {
		return [ 'news', 'carousel' ];
	}

	public function get_script_depends() {
		return [ 'bdevs-elementor'];
	}

	// BDT Position
	protected function element_pack_position() {
	    $position_options = [
	        ''              => esc_html__('Default', 'bdevs-elementor'),
	        'top-left'      => esc_html__('Top Left', 'bdevs-elementor') ,
	        'top-center'    => esc_html__('Top Center', 'bdevs-elementor') ,
	        'top-right'     => esc_html__('Top Right', 'bdevs-elementor') ,
	        'center'        => esc_html__('Center', 'bdevs-elementor') ,
	        'center-left'   => esc_html__('Center Left', 'bdevs-elementor') ,
	        'center-right'  => esc_html__('Center Right', 'bdevs-elementor') ,
	        'bottom-left'   => esc_html__('Bottom Left', 'bdevs-elementor') ,
	        'bottom-center' => esc_html__('Bottom Center', 'bdevs-elementor') , 
	        'bottom-right'  => esc_html__('Bottom Right', 'bdevs-elementor') ,
	    ];

	    return $position_options;
	}

	protected function _register_controls() {
		$this->start_controls_section(
			'section_content_news',
			[
				'label' => esc_html__( 'News', 'bdevs-elementor' ),
			]
		);		
		$this->add_control(
			'title',
			[
				'label'       => __( 'Title', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your title', 'bdevs-elementor' ),
				'default'     => __( 'Title', 'bdevs-elementor' ),
				'label_block' => true,
			]	
		);	
		$this->add_control(
			'number_posts_page_1',
			[
				'label'       => __( 'Number Posts Page type 1', 'bdevs-elementor' ),
				'type'        => Controls_Manager::NUMBER,
				'placeholder' => __( 'Enter your title', 'bdevs-elementor' ),
				'default'     => __( '1', 'bdevs-elementor' ),
				'label_block' => true,
			]	
		);		
		$this->add_control(
			'number_posts_page_2',
			[
				'label'       => __( 'Number Posts Page type 2', 'bdevs-elementor' ),
				'type'        => Controls_Manager::NUMBER,
				'placeholder' => __( 'Enter your title', 'bdevs-elementor' ),
				'default'     => __( '2', 'bdevs-elementor' ),
				'label_block' => true,
			]	
		);		
		$this->add_control(
			'category',
			[
				'label'       => __( 'Category', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your category', 'bdevs-elementor' ),
				'default'     => __( 'Business', 'bdevs-elementor' ),
				'label_block' => true,
			]	
		);	
		$this->add_control(
			'link_new',
			[
				'label'       => __( 'Link Blog', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your link', 'bdevs-elementor' ),
				'default'     => __( '#', 'bdevs-elementor' ),
				'label_block' => true,
			]	
		);		
		$this->add_control(
			'text_new',
			[
				'label'       => __( 'Text All Blog', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your title', 'bdevs-elementor' ),
				'default'     => __( 'Read all news', 'bdevs-elementor' ),
				'label_block' => true,
			]	
		);		
		$this->add_control(
			'tabs',
			[
				'label' => esc_html__( 'Since Items', 'bdevs-elementor' ),
				'type' => Controls_Manager::REPEATER,
				'default' => [
					[
						'tab_title'   => esc_html__( 'Slide #1', 'bdevs-elementor' ),
						'tab_content' => esc_html__( 'I am item content. Click edit button to change this text.', 'bdevs-elementor' ),
					]
				],
				'fields' => [
					[
						'name'        => 'logo',
						'label'       => esc_html__( 'Logo Item', 'bdevs-elementor' ),
						'type'        => Controls_Manager::MEDIA,
						'dynamic'     => [ 'active' => true ],
						'default'     => esc_html__( '' , 'bdevs-elementor' ),
						'label_block' => true,
					],	

				],
			]
		);	

		$this->end_controls_section();

		$this->start_controls_section(
			'section_content_layout',
			[
				'label' => esc_html__( 'Layout', 'bdevs-elementor' ),
			]
		);

		$this->add_responsive_control(
			'align',
			[
				'label'   => esc_html__( 'Alignment', 'bdevs-elementor' ),
				'type'    => Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => esc_html__( 'Left', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-center',
					],
					'right' => [
						'title' => esc_html__( 'Right', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-right',
					],
					'justify' => [
						'title' => esc_html__( 'Justified', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-justify',
					],
				],
				'prefix_class' => 'elementor%s-align-',
				'description'  => 'Use align to match position',
				'default'      => 'left',
			]
		);

		$this->add_control(
			'show_title',
			[
				'label'   => esc_html__( 'Show Title', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);			

		$this->add_control(
			'show_subtitle',
			[
				'label'   => esc_html__( 'Show Subtitle', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);		

		$this->end_controls_section();

	}

	public function render() {

		$settings  = $this->get_settings_for_display();
		extract($settings);
		$bg_src = wp_get_attachment_image_src( $settings['background_bg']['id'], 'full' );
		$bg_url = $bg_src ? $bg_src[0] : '';
		$post_number_1 = wp_kses_post($settings['number_posts_page_1']);
		$post_number_2 = wp_kses_post($settings['number_posts_page_2']);
		$post_category = wp_kses_post($settings['category']);
		?>  

<!--================Latest News Area =================-->
<section class="latest_news_area pad_100">
    <div class="container">
        <div class="row m0">
            <div class="pull-left">
                <div class="left_title">
                    <?php if (( '' !== $settings['title'] ) && ( $settings['show_title'] )) : ?>
		            <h2><?php echo wp_kses_post($settings['title']); ?></h2>
		            <?php endif; ?>
                </div>
            </div>
            <div class="pull-right">
                <a class="read_all" href="<?php echo wp_kses_post($settings['link_new']); ?>"><?php echo wp_kses_post($settings['text_new']); ?></a>
            </div>
        </div>


        <div class="row latest_blog_inner">

			<?php  
                $wp_query = new \WP_Query(array('posts_per_page' => $post_number_1,'post_type' => 'post', 'paged' => $paged,  'orderby' => 'ID', 'order' => 'ASC'));
            	$args = new \WP_Query(array(
                    'post_type'     => 'post',
                    'paged' => $paged,
                ));
                $i = 1;
                while($wp_query->have_posts()): $wp_query->the_post(); 
                $blog_featured_image_3 = get_post_meta(get_the_ID(),'_cmb_featured_image_3', true);            
            ?>
            <div class="col-md-4 col-sm-6">
                <div class="image_blog">
                    <a href="#"><img src="<?php echo wp_get_attachment_url($blog_featured_image_3);?>" alt=""></a>
                    <div class="img_blog_text">
                        <h5><?php the_time(get_option( 'date_format' ));?></h5>
                        <a href="<?php the_permalink();?>"><h3><?php the_title(); ?></h3></a>
                    </div>
                </div>
            </div>
        	<?php endwhile; ?>
	
			<?php  
                $wp_query = new \WP_Query(array('category_name' => $post_category,'posts_per_page' => $post_number_2,'post_type' => 'post', 'paged' => $paged,  'orderby' => 'ID', 'order' => 'ASC'));
            	$args = new \WP_Query(array(
                    'post_type'     => 'post',
                    'paged' => $paged,
                ));
                $i = 1;
                while($wp_query->have_posts()): $wp_query->the_post();           
            ?>
        	<div class="col-md-4 col-sm-6">
                <div class="text_blog">
                    <h5><?php the_time(get_option( 'date_format' ));?></h5>
                    <a href="<?php the_permalink();?>"><h3><?php the_title(); ?></h3></a>
                    <p>
                    	<?php if(isset($sorbroix_redux_demo['blog_excerpt'])){?>
                        <?php echo esc_attr(sorbroix_excerpt($sorbroix_redux_demo['blog_excerpt'])); ?>
                        <?php }else{?>
                        <?php echo esc_attr(sorbroix_excerpt(20)); 
                        ?>
                    	<?php } ?>
                    </p>
                    <div class="blog_user">
                        <h4>by: <a href="#"><?php the_author_posts_link(); ?></a> / <?php echo wp_kses_post($settings['category']); ?></h4>
                    </div>
                </div>
            </div>
            <?php endwhile; ?>
        </div>
        <div class="row m0">
            <div class="client_slider owl-carousel">
            	<?php
		        	foreach ( $settings['tabs'] as $item ) :
		    	?>
                <div class="item">
                    <img src="<?php print wp_kses_post($item['logo']['url']) ?>" alt="">
                </div>
            	<?php endforeach; ?>
            </div>
        </div>
    </div>
</section>
<!--================End Latest News Area =================-->
<?php if (is_admin()) { ?>
    <script type="text/javascript">
    
        
            if ( $('.client_slider').length ){
            $('.client_slider').owlCarousel({
                loop:true,
                margin: 30,
                items: 6,
                nav:false,
                autoplay: true,
                smartSpeed: 1500,
                dots:true,
                responsiveClass: true,
                responsive: {
                    0: {
                        items: 1,
                    },
                    480: {
                        items: 2,
                    },
                    600: {
                        items: 4,
                    },
                    992: {
                        items: 6,
                    }
                }
            })
        }
        
        
    </script>   
    <?php } ?>
<?php
}

}
